@@ -1,5 +1,5 @@
 import re
-from typing import Iterable
+from typing import Any, Iterable, Mapping
 
 from markdown_it import MarkdownIt
 
@@ -9,7 +9,7 @@ import mdformat.plugins
 def is_md_equal(
     md1: str,
     md2: str,
-    options: dict,
+    options: Mapping[str, Any],
     *,
     extensions: Iterable[str] = (),
     codeformatters: Iterable[str] = (),
@@ -27,9 +27,9 @@ def is_md_equal(
         mdformat.plugins.PARSER_EXTENSIONS[extension].update_mdit(mdit)
     for key, text in [("md1", md1), ("md2", md2)]:
         html = mdit.render(text)
-        html = re.sub(r"\s+", "", html)
         for codeclass in codeformatters:
-            html = re.sub(rf'<codeclass="language-{codeclass}">.*</pre>', "", html)
+            html = re.sub(f'<code class="language-{codeclass}">.*</code>', "", html)
+        html = re.sub(r"\s+", "", html)
         html_texts[key] = html
 
     return html_texts["md1"] == html_texts["md2"]
