@@ -1,3 +1,4 @@
+import logging
 from typing import Any, Mapping, Sequence
 
 from markdown_it.token import Token
@@ -7,6 +8,8 @@ from mdformat.renderer._util import MARKERS, removesuffix
 
 __all__ = ("MDRenderer", "MARKERS")
 
+LOGGER = logging.getLogger(__name__)
+
 
 class MDRenderer:
     """Markdown renderer.
